@@ -4,6 +4,7 @@
 
 ################################################################################
 # CHANGE LOG
+# 04: Added option 'console'.
 # 03: Roxygenized.
 # 02: Works with atomic vector.
 
@@ -19,9 +20,11 @@
 #' @param data a data frame in GeneMapper format containing column 'Sample.Name'.
 #' @param ref a data frame in GeneMapper format containing column 'Sample.Name', 
 #'  OR an atomic vector e.g. a single sample name string.
+#' @param console logical, if TRUE result is printed to R console,
+#' if FALSE a string is returned. 
 #' 
 
-checkSubset <- function(data, ref){
+checkSubset <- function(data, ref, console=TRUE){
 
 	# Get reference name(s).
 	if(is.atomic(ref)){
@@ -30,13 +33,24 @@ checkSubset <- function(data, ref){
 		ref.names <- unique(ref$Sample.Name)
 	}
 
+  res <- list()
+	
 	# Subset 'data$Sample.Name' using 'ref.name'.
 	for(n in seq(along=ref.names)){
 
-		print(c("Reference name:",ref.names[n]))
-		print(c("Subsetted samples:"))
-		print(grep(ref.names[n],unique(data$Sample.Name), value=TRUE))
+    cRef <- ref.names[n]
+		cSamples <- grep(ref.names[n],unique(data$Sample.Name), value=TRUE)
+    res[n] <- paste("Reference name: ", cRef, "\n",
+                    "Subsetted samples: ", paste(cSamples, collapse=", "), "\n\n", sep="")
+    
+    
 
 	}
   
-}
\ No newline at end of file
+  if(console){
+    cat(unlist(res))
+  } else {
+    return(unlist(res))
+  }
+  
+}
